@@ -6,20 +6,25 @@
 
 use {
     crate::resource::BytecodeOptimizationLevel,
-    std::{convert::TryFrom, ffi::OsString, os::raw::c_ulong, path::PathBuf, str::FromStr},
+    std::{ffi::OsString, os::raw::c_ulong, path::PathBuf, str::FromStr},
 };
 
+#[cfg(feature = "serialization")]
+use serde::{Deserialize, Serialize};
+
 /// Defines the profile to use to configure a Python interpreter.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum PythonInterpreterProfile {
     /// Python is isolated from the system.
     ///
-    /// See https://docs.python.org/3/c-api/init_config.html#isolated-configuration.
+    /// See <https://docs.python.org/3/c-api/init_config.html#isolated-configuration>.
     Isolated,
 
     /// Python interpreter behaves like `python`.
     ///
-    /// See https://docs.python.org/3/c-api/init_config.html#python-configuration.
+    /// See <https://docs.python.org/3/c-api/init_config.html#python-configuration>.
     Python,
 }
 
@@ -39,6 +44,12 @@ impl ToString for PythonInterpreterProfile {
     }
 }
 
+impl From<PythonInterpreterProfile> for String {
+    fn from(v: PythonInterpreterProfile) -> Self {
+        v.to_string()
+    }
+}
+
 impl TryFrom<&str> for PythonInterpreterProfile {
     type Error = String;
 
@@ -54,8 +65,18 @@ impl TryFrom<&str> for PythonInterpreterProfile {
     }
 }
 
+impl TryFrom<String> for PythonInterpreterProfile {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 /// Defines `terminfo`` database resolution semantics.
 #[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum TerminfoResolution {
     /// Resolve `terminfo` database using appropriate behavior for current OS.
     Dynamic,
@@ -75,6 +96,12 @@ impl ToString for TerminfoResolution {
     }
 }
 
+impl From<TerminfoResolution> for String {
+    fn from(t: TerminfoResolution) -> Self {
+        t.to_string()
+    }
+}
+
 impl TryFrom<&str> for TerminfoResolution {
     type Error = String;
 
@@ -94,8 +121,18 @@ impl TryFrom<&str> for TerminfoResolution {
     }
 }
 
+impl TryFrom<String> for TerminfoResolution {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 /// Defines a backend for a memory allocator.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum MemoryAllocatorBackend {
     /// The default allocator as configured by Python.
     Default,
@@ -132,6 +169,12 @@ impl ToString for MemoryAllocatorBackend {
     }
 }
 
+impl From<MemoryAllocatorBackend> for String {
+    fn from(v: MemoryAllocatorBackend) -> Self {
+        v.to_string()
+    }
+}
+
 impl TryFrom<&str> for MemoryAllocatorBackend {
     type Error = String;
 
@@ -147,10 +190,20 @@ impl TryFrom<&str> for MemoryAllocatorBackend {
     }
 }
 
+impl TryFrom<String> for MemoryAllocatorBackend {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 /// Holds values for coerce_c_locale.
 ///
-/// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.coerce_c_locale.
+/// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.coerce_c_locale>.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum CoerceCLocale {
     #[allow(clippy::upper_case_acronyms)]
     LCCtype = 1,
@@ -167,6 +220,12 @@ impl ToString for CoerceCLocale {
     }
 }
 
+impl From<CoerceCLocale> for String {
+    fn from(v: CoerceCLocale) -> Self {
+        v.to_string()
+    }
+}
+
 impl TryFrom<&str> for CoerceCLocale {
     type Error = String;
 
@@ -179,10 +238,20 @@ impl TryFrom<&str> for CoerceCLocale {
     }
 }
 
+impl TryFrom<String> for CoerceCLocale {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 /// Defines what to do when comparing bytes with str.
 ///
-/// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.bytes_warning.
+/// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.bytes_warning>.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum BytesWarning {
     None = 0,
     Warn = 1,
@@ -200,6 +269,12 @@ impl ToString for BytesWarning {
     }
 }
 
+impl From<BytesWarning> for String {
+    fn from(v: BytesWarning) -> Self {
+        v.to_string()
+    }
+}
+
 impl TryFrom<&str> for BytesWarning {
     type Error = String;
 
@@ -213,6 +288,14 @@ impl TryFrom<&str> for BytesWarning {
     }
 }
 
+impl TryFrom<String> for BytesWarning {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 impl From<i32> for BytesWarning {
     fn from(value: i32) -> BytesWarning {
         match value {
@@ -223,8 +306,10 @@ impl From<i32> for BytesWarning {
     }
 }
 
-/// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.check_hash_pycs_mode.
+/// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.check_hash_pycs_mode>.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum CheckHashPycsMode {
     Always,
     Never,
@@ -242,6 +327,12 @@ impl ToString for CheckHashPycsMode {
     }
 }
 
+impl From<CheckHashPycsMode> for String {
+    fn from(v: CheckHashPycsMode) -> Self {
+        v.to_string()
+    }
+}
+
 impl TryFrom<&str> for CheckHashPycsMode {
     type Error = String;
 
@@ -258,8 +349,18 @@ impl TryFrom<&str> for CheckHashPycsMode {
     }
 }
 
-/// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.allocator.
+impl TryFrom<String> for CheckHashPycsMode {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
+/// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.allocator>.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum Allocator {
     NotSet = 0,
     Default = 1,
@@ -285,6 +386,12 @@ impl ToString for Allocator {
     }
 }
 
+impl From<Allocator> for String {
+    fn from(v: Allocator) -> Self {
+        v.to_string()
+    }
+}
+
 impl TryFrom<&str> for Allocator {
     type Error = String;
 
@@ -302,8 +409,18 @@ impl TryFrom<&str> for Allocator {
     }
 }
 
+impl TryFrom<String> for Allocator {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 /// Defines how to call `multiprocessing.set_start_method()` when `multiprocessing` is imported.
 #[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(try_from = "String", into = "String"))]
 pub enum MultiprocessingStartMethod {
     /// Do not call `multiprocessing.set_start_method()`.
     None,
@@ -330,6 +447,12 @@ impl ToString for MultiprocessingStartMethod {
     }
 }
 
+impl From<MultiprocessingStartMethod> for String {
+    fn from(v: MultiprocessingStartMethod) -> Self {
+        v.to_string()
+    }
+}
+
 impl FromStr for MultiprocessingStartMethod {
     type Err = String;
 
@@ -345,6 +468,22 @@ impl FromStr for MultiprocessingStartMethod {
     }
 }
 
+impl TryFrom<&str> for MultiprocessingStartMethod {
+    type Error = String;
+
+    fn try_from(v: &str) -> Result<Self, Self::Error> {
+        Self::from_str(v)
+    }
+}
+
+impl TryFrom<String> for MultiprocessingStartMethod {
+    type Error = String;
+
+    fn try_from(value: String) -> Result<Self, Self::Error> {
+        Self::try_from(value.as_str())
+    }
+}
+
 /// Holds configuration of a Python interpreter.
 ///
 /// This struct holds fields that are exposed by `PyPreConfig` and
@@ -354,173 +493,291 @@ impl FromStr for MultiprocessingStartMethod {
 /// `PyPreConfig` and `PyConfig`), all fields are optional. Only fields
 /// with `Some(T)` will be updated from the defaults.
 #[derive(Clone, Debug, Default, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", serde(default))]
 pub struct PythonInterpreterConfig {
     /// Profile to use to initialize pre-config and config state of interpreter.
     pub profile: PythonInterpreterProfile,
 
     // The following fields are from PyPreConfig or are shared with PyConfig.
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.allocator.
+    /// Name of the memory allocator.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.allocator>.
     pub allocator: Option<Allocator>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.configure_locale.
+    /// Whether to set the LC_CTYPE locale to the user preferred locale.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.configure_locale>.
     pub configure_locale: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.coerce_c_locale.
+    /// How to coerce the locale settings.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.coerce_c_locale>.
     pub coerce_c_locale: Option<CoerceCLocale>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.coerce_c_locale_warn.
+    /// Whether to emit a warning if the C locale is coerced.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.coerce_c_locale_warn>.
     pub coerce_c_locale_warn: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.dev_mode.
+    /// Whether to enable Python development mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.dev_mode>.
     pub development_mode: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.isolated.
+    /// Isolated mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.isolated>.
     pub isolated: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.legacy_windows_fs_encoding.
+    /// Whether to use legacy filesystem encodings on Windows.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.legacy_windows_fs_encoding>.
     pub legacy_windows_fs_encoding: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.parse_argv.
+    /// Whether argv should be parsed the way `python` parses them.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.parse_argv>.
     pub parse_argv: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.use_environment.
+    /// Whether environment variables are read to control the interpreter configuration.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.use_environment>.
     pub use_environment: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.utf8_mode.
+    /// Controls Python UTF-8 mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyPreConfig.utf8_mode>.
     pub utf8_mode: Option<bool>,
     // The following fields are from PyConfig.
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.argv.
+    /// Command line arguments.
+    ///
+    /// These will become `sys.argv`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.argv>.
     pub argv: Option<Vec<OsString>>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.base_exec_prefix.
+    /// Controls `sys.base_exec_prefix`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.base_exec_prefix>.
     pub base_exec_prefix: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.base_executable.
+    /// Controls `sys._base_executable`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.base_executable>.
     pub base_executable: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.base_prefix.
+    /// Controls `sys.base_prefix`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.base_prefix>.
     pub base_prefix: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.buffered_stdio.
+    /// Controls buffering on `stdout` and `stderr`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.buffered_stdio>.
     pub buffered_stdio: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.bytes_warning.
+    /// Controls warnings/errors for some bytes type coercions.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.bytes_warning>.
     pub bytes_warning: Option<BytesWarning>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.check_hash_pycs_mode.
+    /// Validation mode for `.pyc` files.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.check_hash_pycs_mode>.
     pub check_hash_pycs_mode: Option<CheckHashPycsMode>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.configure_c_stdio.
+    /// Controls binary mode and buffering on C standard streams.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.configure_c_stdio>.
     pub configure_c_stdio: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.dump_refs.
+    /// Dump Python references.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.dump_refs>.
     pub dump_refs: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.exec_prefix.
+    /// Controls `sys.exec_prefix`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.exec_prefix>.
     pub exec_prefix: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.executable.
+    /// Controls `sys.executable`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.executable>.
     pub executable: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.faulthandler.
+    /// Enable `faulthandler`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.faulthandler>.
     pub fault_handler: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.filesystem_encoding.
+    /// Controls the encoding to use for filesystems/paths.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.filesystem_encoding>.
     pub filesystem_encoding: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.filesystem_errors.
+    /// Filesystem encoding error handler.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.filesystem_errors>.
     pub filesystem_errors: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.hash_seed.
+    /// Randomized hash function seed.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.hash_seed>.
     pub hash_seed: Option<c_ulong>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.home.
+    /// Python home directory.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.home>.
     pub home: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.import_time.
+    /// Whether to profile `import` time.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.import_time>.
     pub import_time: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.inspect.
+    /// Enter interactive mode after executing a script or a command.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.inspect>.
     pub inspect: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.install_signal_handlers.
+    /// Whether to install Python signal handlers.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.install_signal_handlers>.
     pub install_signal_handlers: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.interactive.
+    /// Whether to enable the interactive REPL mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.interactive>.
     pub interactive: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.legacy_windows_stdio.
+    /// Controls legacy stdio behavior on Windows.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.legacy_windows_stdio>.
     pub legacy_windows_stdio: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.malloc_stats.
+    /// Whether to dump statistics from the `pymalloc` allocator on exit.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.malloc_stats>.
     pub malloc_stats: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.module_search_paths.
+    /// Defines `sys.path`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.module_search_paths>.
     pub module_search_paths: Option<Vec<PathBuf>>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.optimization_level.
+    /// Bytecode optimization level.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.optimization_level>.
     pub optimization_level: Option<BytecodeOptimizationLevel>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.parser_debug.
+    /// Parser debug mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.parser_debug>.
     pub parser_debug: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.pathconfig_warnings.
+    /// Whether calculating the Python path configuration can emit warnings.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.pathconfig_warnings>.
     pub pathconfig_warnings: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.prefix.
+    /// Defines `sys.prefix`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.prefix>.
     pub prefix: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.program_name.
+    /// Program named used to initialize state during path configuration.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.program_name>.
     pub program_name: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.pycache_prefix.
+    /// Directory where `.pyc` files are written.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.pycache_prefix>.
     pub pycache_prefix: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.pythonpath_env.
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.pythonpath_env>.
     pub python_path_env: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.quiet.
+    /// Quiet mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.quiet>.
     pub quiet: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.run_command.
+    /// Value of the `-c` command line option.
+    ///
+    /// Effectively defines Python code to evaluate in `Py_RunMain()`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.run_command>.
     pub run_command: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.run_filename.
+    /// Filename passed on the command line.
+    ///
+    /// Effectively defines the Python file to run in `Py_RunMain()`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.run_filename>.
     pub run_filename: Option<PathBuf>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.run_module.
+    /// Value of the `-m` command line option.
+    ///
+    /// Effectively defines the Python module to run as `__main__` in `Py_RunMain()`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.run_module>.
     pub run_module: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.show_ref_count.
+    /// Whether to show the total reference count at exit.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.show_ref_count>.
     pub show_ref_count: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.site_import.
+    /// Whether to import the `site` module at startup.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.site_import>.
     pub site_import: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.skip_source_first_line.
+    /// Whether to skip the first line of [Self::run_filename].
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.skip_source_first_line>.
     pub skip_first_source_line: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.stdio_encoding.
+    /// Encoding of `sys.stdout`, `sys.stderr`, and `sys.stdin`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.stdio_encoding>.
     pub stdio_encoding: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.stdio_errors.
+    /// Encoding error handler for `sys.stdout` and `sys.stdin`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.stdio_errors>.
     pub stdio_errors: Option<String>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.tracemalloc.
+    /// Whether to enable `tracemalloc`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.tracemalloc>.
     pub tracemalloc: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.user_site_directory.
+    /// Whether to add the user site directory to `sys.path`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.user_site_directory>.
     pub user_site_directory: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.verbose.
+    /// Verbose mode.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.verbose>.
     pub verbose: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.warnoptions.
+    /// Options of the `warning` module to control behavior.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.warnoptions>.
     pub warn_options: Option<Vec<String>>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.write_bytecode.
+    /// Controls `sys.dont_write_bytecode`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.write_bytecode>.
     pub write_bytecode: Option<bool>,
 
-    /// See https://docs.python.org/3/c-api/init_config.html#c.PyConfig.xoptions.
+    /// Values of the `-X` command line options / `sys._xoptions`.
+    ///
+    /// See <https://docs.python.org/3/c-api/init_config.html#c.PyConfig.xoptions>.
     pub x_options: Option<Vec<String>>,
 }
