@@ -14,20 +14,25 @@ use {
     std::{
         borrow::Cow,
         collections::HashMap,
-        convert::TryFrom,
         hash::BuildHasher,
-        iter::FromIterator,
         path::{Path, PathBuf},
     },
     tugger_file_manifest::{File, FileData},
     tugger_licensing::LicensedComponent,
 };
 
+#[cfg(feature = "serialization")]
+use serde::{Deserialize, Serialize};
+
 /// An optimization level for Python bytecode.
 #[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub enum BytecodeOptimizationLevel {
+    #[cfg_attr(feature = "serialization", serde(rename = "0"))]
     Zero,
+    #[cfg_attr(feature = "serialization", serde(rename = "1"))]
     One,
+    #[cfg_attr(feature = "serialization", serde(rename = "2"))]
     Two,
 }
 
@@ -90,6 +95,10 @@ pub struct PythonModuleSource {
 }
 
 impl PythonModuleSource {
+    pub fn description(&self) -> String {
+        format!("source code for Python module {}", self.name)
+    }
+
     pub fn to_memory(&self) -> Result<Self> {
         Ok(Self {
             name: self.name.clone(),
@@ -176,6 +185,13 @@ pub struct PythonModuleBytecodeFromSource {
 }
 
 impl PythonModuleBytecodeFromSource {
+    pub fn description(&self) -> String {
+        format!(
+            "bytecode for Python module {} at O{} (compiled from source)",
+            self.name, self.optimize_level as i32
+        )
+    }
+
     pub fn to_memory(&self) -> Result<Self> {
         Ok(Self {
             name: self.name.clone(),
@@ -277,6 +293,13 @@ impl PythonModuleBytecode {
         }
     }
 
+    pub fn description(&self) -> String {
+        format!(
+            "bytecode for Python module {} at O{}",
+            self.name, self.optimize_level as i32
+        )
+    }
+
     pub fn to_memory(&self) -> Result<Self> {
         Ok(Self {
             name: self.name.clone(),
@@ -340,6 +363,10 @@ pub struct PythonPackageResource {
 }
 
 impl PythonPackageResource {
+    pub fn description(&self) -> String {
+        format!("Python package resource {}", self.symbolic_name())
+    }
+
     pub fn to_memory(&self) -> Result<Self> {
         Ok(Self {
             leaf_package: self.leaf_package.clone(),
@@ -407,6 +434,13 @@ pub struct PythonPackageDistributionResource {
 }
 
 impl PythonPackageDistributionResource {
+    pub fn description(&self) -> String {
+        format!(
+            "Python package distribution resource {}:{}",
+            self.package, self.name
+        )
+    }
+
     pub fn to_memory(&self) -> Result<Self> {
         Ok(Self {
             location: self.location.clone(),
@@ -519,6 +553,12 @@ impl TryFrom<&LibraryDependency> for SharedLibrary {
     }
 }
 
+impl SharedLibrary {
+    pub fn description(&self) -> String {
+        format!("shared library {}", self.name)
+    }
+}
+
 /// Represents a Python extension module.
 #[derive(Clone, Debug, PartialEq)]
 pub struct PythonExtensionModule {
@@ -558,6 +598,10 @@ pub struct PythonExtensionModule {
 }
 
 impl PythonExtensionModule {
+    pub fn description(&self) -> String {
+        format!("Python extension module {}", self.name)
+    }
+
     pub fn to_memory(&self) -> Result<Self> {
         Ok(Self {
             name: self.name.clone(),
@@ -646,17 +690,11 @@ impl PythonExtensionModule {
 }
 
 /// Represents a collection of variants for a given Python extension module.
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Default)]
 pub struct PythonExtensionModuleVariants {
     extensions: Vec<PythonExtensionModule>,
 }
 
-impl Default for PythonExtensionModuleVariants {
-    fn default() -> Self {
-        Self { extensions: vec![] }
-    }
-}
-
 impl FromIterator<PythonExtensionModule> for PythonExtensionModuleVariants {
     fn from_iter<I: IntoIterator<Item = PythonExtensionModule>>(iter: I) -> Self {
         Self {
@@ -801,7 +839,7 @@ impl<'a> PythonResource<'a> {
             // name matches through the filter because this makes sense for filtering.
             // The package annotation is really only useful to influence file layout,
             // when __init__.py files need to be materialized.
-            if name == package || packages_from_module_name(&name).contains(package) {
+            if name == package || packages_from_module_name(name).contains(package) {
                 return true;
             }
         }
